==> haskell-entropy-0.4.1.7-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 entropy
version:              0.4.1.7
visibility:           public
id:                   entropy-0.4.1.7-66OkMQHXKESGwpio7bQXje
key:                  entropy-0.4.1.7-66OkMQHXKESGwpio7bQXje
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             https://github.com/TomMD/entropy
synopsis:             A platform independent entropy source
description:
    A mostly platform independent method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.

category:             Data, Cryptography
abi:                  ec5a25a0794a3af46ebb3fde6148d858
exposed:              True
exposed-modules:      System.Entropy
hidden-modules:       System.EntropyNix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/entropy-0.4.1.7
library-dirs:         /usr/lib/ghc-9.0.1/site-local/entropy-0.4.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/entropy-0.4.1.7
hs-libraries:         HSentropy-0.4.1.7-66OkMQHXKESGwpio7bQXje
depends:              base-4.15.0.0 bytestring-0.10.12.1 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html:         /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-entropy-0.4.1.10-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 entropy
version:              0.4.1.10
visibility:           public
id:                   entropy-0.4.1.10-CwQzC5Ky39pHQuKDZJMypk
key:                  entropy-0.4.1.10-CwQzC5Ky39pHQuKDZJMypk
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             https://github.com/TomMD/entropy
synopsis:             A platform independent entropy source
description:
    A mostly platform independent method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.

category:             Data, Cryptography
abi:                  7c8b1426805e33a2d64e0a5b885d5e33
exposed:              True
exposed-modules:      System.Entropy
hidden-modules:       System.EntropyNix
import-dirs:          /usr/lib/ghc-9.0.2/site-local/entropy-0.4.1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/entropy-0.4.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-entropy
hs-libraries:         HSentropy-0.4.1.10-CwQzC5Ky39pHQuKDZJMypk
depends:              base-4.15.1.0 bytestring-0.10.12.1 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html:         /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
